<?php

namespace Drupal\entity_usage_explorer;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\paragraphs\Entity\Paragraph;
use Twig\Extension\AbstractExtension;
use Twig\TwigFilter;
use Twig\TwigFunction;

/**
 * Custom twig functions for entity_usage_explorer.
 */
class UsageHelper extends AbstractExtension {

  /**
   * The entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a UsageHelper object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager service.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public function getFilters() {
    return [
      new TwigFilter('instanceof_content_entity', [$this, 'isInstanceOfContentEntity']),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFunctions() {
    return [
      new TwigFunction('loadParagraphParent', [$this, 'loadParagraphParent']),
    ];
  }

  /**
   * Return parent entity of a paragraph.
   */
  public function loadParagraphParent($pid) {
    $paragraph = $this->entityTypeManager->getStorage('paragraph')->load($pid);
    if (!($paragraph instanceof Paragraph)) {
      return NULL;
    }
    return $paragraph?->getParentEntity();
  }

}
